@@ -11,6 +11,9 @@
     dp_playerids,
     nflfastr_weekly,
     nflfastr_rosters,
+    .nflfastr_kicking_long,
+    .nflfastr_offense_long,
+    .nflfastr_roster,
     mfl_players,
     sleeper_players,
     espn_players,
@@ -51,5 +54,5 @@
     ff_schedule.espn_conn
   )
 
-  purrr::walk(functions, memoise::forget)
+  lapply(functions, memoise::forget)
 }
