@@ -21,7 +21,9 @@
 espn_potentialpoints <- function(conn, weeks = 1:17) {
   player_weeks <- ff_starters(conn, weeks)
 
-  if(is.null(player_weeks)) return(NULL)
+  if (is.null(player_weeks)) {
+    return(NULL)
+  }
 
   player_weeks <- player_weeks %>%
     dplyr::rename(
