@@ -6,8 +6,8 @@
 #' @examples
 #' \donttest{
 #' try({ # try only shown here because sometimes CRAN checks are weird
-#' x <- sleeper_players()
-#' dplyr::sample_n(x,5)
+#'   x <- sleeper_players()
+#'   dplyr::sample_n(x, 5)
 #' }) # end try
 #' }
 #'
@@ -23,7 +23,8 @@ sleeper_players <- function() {
     dplyr::mutate_at("birth_date", lubridate::as_date) %>%
     dplyr::mutate(
       age = round(as.numeric(Sys.Date() - .data$birth_date) / 365.25, 1),
-      gsis_id = stringr::str_squish(gsis_id)) %>%
+      gsis_id = stringr::str_squish(gsis_id)
+    ) %>%
     dplyr::select(-dplyr::contains("search"), -dplyr::contains("first_name"), -dplyr::contains("last_name"), -dplyr::contains("metadata")) %>%
     dplyr::select(
       "player_id",
