@@ -18,18 +18,19 @@ test_that("dp_cleannames removes periods, apostrophes, and suffixes", {
 
   expect_equal(cleaned_names, c("AJ Green", "Odell Beckham", "LeVeon Bell"))
   expect_equal(lowercase_clean, c("aj green", "odell beckham", "leveon bell"))
-
 })
 
 test_that("dp_cleannames fixes MFL names and does custom name substitutions", {
-
-  mixed_names <- c("Trubisky, Mitch", "Chatarius Atwell",
-                   "Zeke Elliott", "Devante Parker",
-                   "A.J. Green", "Beckham Jr., Odell")
+  mixed_names <- c(
+    "Trubisky, Mitch", "Chatarius Atwell",
+    "Zeke Elliott", "Devante Parker",
+    "A.J. Green", "Beckham Jr., Odell"
+  )
 
   custom_cleaned_names <- dp_cleannames(mixed_names, convert_lastfirst = TRUE, use_name_database = TRUE)
 
   expect_equal(
     custom_cleaned_names,
-    c("Mitchell Trubisky", "Tutu Atwell", "Ezekiel Elliott", "DeVante Parker", "AJ Green", "Odell Beckham"))
+    c("Mitchell Trubisky", "Tutu Atwell", "Ezekiel Elliott", "DeVante Parker", "AJ Green", "Odell Beckham")
+  )
 })
